com.oakmac.tourney-nerd.fields


create-fieldclj/s

(create-field order name)

creates a single Field

creates a single Field
sourceraw docstring

create-n-fieldsclj/s

(create-n-fields num-fields)

returns a map of N Fields; used for Event creation

returns a map of N Fields; used for Event creation
sourceraw docstring

get-field-by-idclj/s

(get-field-by-id event field-id)

Returns the Field with field-id from an Event, nil otherwise. The Event may be keyed by string or keyword.

Returns the Field with field-id from an Event, nil otherwise.
The Event may be keyed by string or keyword.
sourceraw docstring

valid-field?clj/s

(valid-field? f)

Is f a valid Field?

Is f a valid Field?
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries