com.oakmac.tourney-nerd.groups


all-games-final?clj/s

(all-games-final? event group-id)

Have all of the games in this group been played? ie: are they all STATUS_FINAL?

Have all of the games in this group been played? ie: are they all STATUS_FINAL?
sourceraw docstring

ensure-groups-orderclj/s

(ensure-groups-order groups)

Ensures that all groups have a sequential :order field per division

Ensures that all groups have a sequential :order field per division
sourceraw docstring

get-all-games-for-groupclj/s

(get-all-games-for-group event group-id)

returns a map of all the games for a given group-id

returns a map of all the games for a given group-id
sourceraw docstring

get-group-by-idclj/s

(get-group-by-id event group-id)

Returns the Group with group-id from an Event, nil otherwise. The Event may be keyed by string or keyword.

Returns the Group with group-id from an Event, nil otherwise.
The Event may be keyed by string or keyword.
sourceraw docstring

get-teams-for-groupclj/s

(get-teams-for-group event group-id)

returns a map of all the teams for a given group-id

returns a map of all the teams for a given group-id
sourceraw docstring

group->game-countsclj/s

(group->game-counts event group-id)

Returns how many of a Group's games have been played. See games->counts. {:total 30, :final 9, :remaining 21}

Returns how many of a Group's games have been played. See games->counts.
{:total 30, :final 9, :remaining 21}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries