(create-timeslot time name)creates a single Timeslot
creates a single Timeslot
(create-timeslots-from-template template-timeslots days)creates a Schedule from a template; used for Event Creation
creates a Schedule from a template; used for Event Creation
(get-days schedule)returns a sorted collection of the unique days in a Schedule
returns a sorted collection of the unique days in a Schedule
(get-timeslot-by-id event timeslot-id)Returns the Timeslot with timeslot-id from an Event's :schedule, nil otherwise. The Event may be keyed by string or keyword.
Returns the Timeslot with timeslot-id from an Event's :schedule, nil otherwise. The Event may be keyed by string or keyword.
(schedule->times-set schedule)returns a Set of the times on the Schedule
returns a Set of the times on the Schedule
(timeslot-on-date? timeslot date)Does this timeslot occur on this date?
Does this timeslot occur on this date?
(ts->date ts)returns the date part from an ISO 8601 string
returns the date part from an ISO 8601 string
(valid-time? ts)Is this time string valid?
Is this time string valid?
(valid-timeslot? ts)Is ts a valid Timeslot?
Is ts a valid Timeslot?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |