com.oakmac.tourney-nerd.teams


create-n-teamsclj/s

(create-n-teams division-id num-teams)

returns a map of N Teams; used for Event Creation

returns a map of N Teams; used for Event Creation
sourceraw docstring

create-teamclj/s

(create-team opts)

Creates a single team

Creates a single team
sourceraw docstring

get-team-by-idclj/s

(get-team-by-id event team-id)

Returns the Team with team-id from an Event, nil otherwise. The Event may be keyed by string or keyword.

Returns the Team with team-id from an Event, nil otherwise.
The Event may be keyed by string or keyword.
sourceraw docstring

reset-teamclj/s

(reset-team {:keys [seed] :as team})

Resets the values of a Team for a new Event.

Resets the values of a Team for a new Event.
sourceraw docstring

team?clj/s

(team? t)

Does t look like a Team? A loose check used to recognize Teams when walking an Event. See valid-team? for a strict check.

Does t look like a Team? A loose check used to recognize Teams when walking an
Event. See valid-team? for a strict check.
sourceraw docstring

teams->sorted-by-seedclj/s

(teams->sorted-by-seed teams)

Convert teams into a list ordered by their seed.

Convert teams into a list ordered by their seed.
sourceraw docstring

valid-team?clj/s

(valid-team? t)

Is t a well-formed Team? Checks every field, including seed. See team? to recognize Teams inside an Event.

Is t a well-formed Team? Checks every field, including seed.
See team? to recognize Teams inside an Event.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries