com.oakmac.tourney-nerd.util


create-uuidclj/s

(create-uuid)
source

get-by-idclj/s

(get-by-id items id)

Returns the item with id from items, a map of items keyed by their id. items may be keyed by string or keyword, and id may be a string or keyword. Returns nil when there is no such item.

Returns the item with id from items, a map of items keyed by their id.
items may be keyed by string or keyword, and id may be a string or keyword.
Returns nil when there is no such item.
sourceraw docstring

halfclj/s

(half x)
source

one?clj/s

(one? x)
source

str->intclj/s

(str->int s)

convert s to an Integer

convert s to an Integer
sourceraw docstring

string-of-length?clj/s

(string-of-length? s min-len max-len)

Is s a String with a length between min-len and max-len (inclusive)?

Is s a String with a length between min-len and max-len (inclusive)?
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries