(all-games-final? event group-id)Have all of the games in this group been played? ie: are they all STATUS_FINAL?
Have all of the games in this group been played? ie: are they all STATUS_FINAL?
(ensure-groups-order groups)Ensures that all groups have a sequential :order field per division
Ensures that all groups have a sequential :order field per division
(get-all-games-for-group event group-id)returns a map of all the games for a given group-id
returns a map of all the games for a given group-id
(get-group-by-id event group-id)Returns the Group with group-id from an Event, nil otherwise. The Event may be keyed by string or keyword.
Returns the Group with group-id from an Event, nil otherwise. The Event may be keyed by string or keyword.
(get-teams-for-group event group-id)returns a map of all the teams for a given group-id
returns a map of all the teams for a given group-id
(group->game-counts event group-id)Returns how many of a Group's games have been played. See games->counts. {:total 30, :final 9, :remaining 21}
Returns how many of a Group's games have been played. See games->counts.
{:total 30, :final 9, :remaining 21}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |