(create-n-teams division-id num-teams)returns a map of N Teams; used for Event Creation
returns a map of N Teams; used for Event Creation
(get-team-by-id event team-id)Returns the Team with team-id from an Event, nil otherwise. The Event may be keyed by string or keyword.
Returns the Team with team-id from an Event, nil otherwise. The Event may be keyed by string or keyword.
(reset-team {:keys [seed] :as team})Resets the values of a Team for a new Event.
Resets the values of a Team for a new Event.
(team? t)Does t look like a Team? A loose check used to recognize Teams when walking an Event. See valid-team? for a strict check.
Does t look like a Team? A loose check used to recognize Teams when walking an Event. See valid-team? for a strict check.
(teams->sorted-by-seed teams)Convert teams into a list ordered by their seed.
Convert teams into a list ordered by their seed.
(valid-team? t)Is t a well-formed Team? Checks every field, including seed. See team? to recognize Teams inside an Event.
Is t a well-formed Team? Checks every field, including seed. See team? to recognize Teams inside an Event.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |