(get-by-id items id)Returns the item with id from items, a map of items keyed by their id. items may be keyed by string or keyword, and id may be a string or keyword. Returns nil when there is no such item.
Returns the item with id from items, a map of items keyed by their id. items may be keyed by string or keyword, and id may be a string or keyword. Returns nil when there is no such item.
(string-of-length? s min-len max-len)Is s a String with a length between min-len and max-len (inclusive)?
Is s a String with a length between min-len and max-len (inclusive)?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |